[![PyPI version](https://badge.fury.io/py/lyrics-displayer.svg)](https://badge.fury.io/py/lyrics-displayer)

Lyrics Displayer
----------------

Lyrics Displayer automatically detects what song is playing on a
music player connected to the same network.

It then queries lyrics from various online sources and displays
the lyrics to the command line (attempting to estimate the current
position in the song).


Supported Players
-----------------

  - Sonos


Lyrics Sources
--------------

Integrates with [lyricfetch](https://github.com/ocaballeror/LyricFetch)
which has an extensive list of supported sources.


Usage
-----

To use simply, in command line do::

    >>> sing-along


Installation
-----------

    >>> pip install lyrics-displayer
